/*
VeraParser.jj - JavaCC parser definition for the Vera language
Copyright (C) 2003 Trevor A. Robinson

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package com.scurrilous.parser.vera;

import java.io.*;

public class VeraParserTest
{
    public static void main(String[] args)
    {
        try {
            CharArrayWriter writer = new CharArrayWriter();

            VeraPPParser ppparser;
            if (args.length > 0) {
                File inFile = new File(args[0]);
                System.out.println("Input file: " + inFile);
                ppparser = new VeraPPParser(inFile.getPath(), writer);

                File inFileDir = inFile.getCanonicalFile().getParentFile();
                System.out.println("Adding search path: " + inFileDir);
                ppparser.addUserPath(inFileDir.getPath());
            } else {
                System.out.println("Reading from stdin");
                ppparser = new VeraPPParser(System.in);
                ppparser.setFilename("stdin");
                ppparser.setOutput(writer);
            }
            ppparser.file();
            System.out.println("Preprocessing successful");

            CharArrayReader reader = new CharArrayReader(writer.toCharArray());

            VeraParser parser = new VeraParser(reader);
            parser.translation_unit();
            System.out.println("Parsing successful");
        }
        catch (Throwable t) {
            t.printStackTrace();
        }
    }
}

